@@ -7,15 +7,20 @@
 from . import PostProcess as PP
 from . import GeneralMap as GM
 
-def ApplyScriptDefaults(Strng,Source,Target):
+def ApplyScriptDefaults(Strng,Source,Target, PostOptions=[]):
     Options = []
 
+    #print('Target is ' + Target)
+
     if Target in GM.IndicScripts:
         Options += []#['RemoveDiacritics'] #Sometimes you may wanna keep it. Adjust options
 
     if Target == 'Telugu' or Target == 'Kannada':
         Options += ['NasalToAnusvara','MToAnusvara']
 
+    elif Target == 'Nandinagari':
+        Options += ['NasalToAnusvara']
+
     elif Target == 'Hebrew':
         Options += ['HebrewVetVav', 'HebrewnonFinalShort']
 
@@ -26,7 +31,10 @@ def ApplyScriptDefaults(Strng,Source,Target):
         Options += ['TamilNaToNNa','AnusvaraToNasal', 'TamilpredictDentaNa']
 
     elif Target == 'Bengali':
-        Options += ['VaToBa','YaToYYa']
+        if 'BengaliRaBa' in PostOptions:
+            Options += ['YaToYYa','AnusvaraToNasal']
+        else:
+            Options += ['VaToBa','YaToYYa','AnusvaraToNasal']
 
     elif Target == 'MeeteiMayek':
         Options += ['MeeteiMayekremoveHistorical']
@@ -35,10 +43,10 @@ def ApplyScriptDefaults(Strng,Source,Target):
         Options += ['LimburemoveHistorical']
 
     elif Target == 'Assamese':
-        Options += ['YaToYYa']
+        Options += ['YaToYYa','AnusvaraToNasal']
 
     elif Target == 'Oriya':
-        Options += ['OriyaVa','YaToYYa']
+        Options += ['OriyaVa','YaToYYa','AnusvaraToNasal']
 
     elif Target == 'Chakma':
         Options += ['YaToYYa']
@@ -73,6 +81,20 @@ def ApplyScriptDefaults(Strng,Source,Target):
     elif Target == "WarangCiti":
         Options += ['WarangCitiModernOrthogaphy']
 
+    elif Target == "Latn":
+        ## Also make changes in FixSemiticPreProcess
+        if Source == 'Arab':
+            Options += ['arabizeLatn']
+        elif Source == 'Arab-Ur' or Source == 'Arab-Pa' or Source == 'Arab-Fa':
+            Options += ['urduizeLatn']
+        elif Source == 'Syrn':
+            Options += ['syricizeLatn']
+        elif Source == 'Syrj' or Source == 'Hebr':
+            Options += ['hebraizeLatn']
+
+    elif Target == "Arab":
+        Options += ['ArabRemoveAdditions']
+
     else:
         Options += []
 
