@@ -144,7 +144,7 @@ SinhalaConsonantMap =[
                       ]
 
 NuktaMap = [
-           '\u02BD'
+           '\u02BD\u02BD\u02BD\u02BD'
            ]
 
 OmMap = [
